@@ -1,15 +1,15 @@
 man.evenn <-
 function()
 {
-	write("        ,.-.,                                                                         ", file="")
-	write("      .`     `.                                                                       ", file="")
-	write("     /.-., ,.-.`            *       *                                 ****     ****   ", file="")
-	write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *    *  ", file="")
-	write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *        *   ", file="")
-	write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *         *   ", file="")
-	write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *       *    *  ", file="")
-	write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** *  ****   ", file="")
-	write("     `'-'` `'-'`                                                                      ", file="")
+	write("        ,.-.,                                                                                   ", file="")
+	write("      .`     `.                                                                                 ", file="")
+	write("     /.-., ,.-.`            *       *                                 ****     ****    *******  ", file="")
+	write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *    *   *        ", file="")
+	write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *        *    ******   ", file="")
+	write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *         *          *  ", file="")
+	write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *       *    *         *  ", file="")
+	write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** *  ****  * ******   ", file="")
+	write("     `'-'` `'-'`                                                                                ", file="")
 	write("\n#####################", file="")
 	write("# eVenn Quick Start #", file="")
 	write("#####################", file="")
